..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Changes
=======

Version 1.1.0 (released 2020-12-09)

- Integrates Semantic-UI templates
- Migrates CI to GitHub actions

Version 1.0.3 (released 2020-05-06)

- Deprecated Python versions lower than 3.6.0. Now supporting 3.6.0 and 3.7.0

Version 1.0.2 (released 2019-07-29)

- Adds HTML sanitization Jinja filter.

Version 1.0.1 (released 2018-05-25)

- Fixes issue with badges being cached.

Version 1.0.0 (released 2018-03-23)

- Initial public release.
